from setuptools import setup

setup(name='statisticdistribution',
      author= 'Luter .C. Aondona',
      email = 'luteraondona@gmail.com',
      version='0.1',
      description='Gaussian and binomial distributions',
      packages=['statisticdistribution'],
      zip_safe=False)
